WasmRpc

Struct WasmRpc 

pub struct WasmRpc { /* private fields */ }
An RPC client for invoking remote agents

Implementations

Source

impl WasmRpc

pub fn new( agent_type_name: &str, constructor: &DataValue, phantom_id: Option<Uuid>, agent_config: &[TypedAgentConfigValue], ) -> Self

Constructs the RPC client connecting to the given target agent

Source

impl WasmRpc

pub fn invoke_and_await( &self, method_name: &str, input: &DataValue, ) -> Result<DataValue, RpcError>

Invokes a remote method with the given parameters, and awaits the result

Source

impl WasmRpc

pub fn invoke( &self, method_name: &str, input: &DataValue, ) -> Result<(), RpcError>

Triggers the invocation of a remote method with the given parameters, and returns immediately.

Source

impl WasmRpc

pub fn async_invoke_and_await( &self, method_name: &str, input: &DataValue, ) -> FutureInvokeResult

Invokes a remote method with the given parameters, and returns a future-invoke-result value which can be polled for the result.

With this function it is possible to call multiple (different) agents simultaneously.

Source

impl WasmRpc

pub fn schedule_invocation( &self, scheduled_time: Datetime, method_name: &str, input: &DataValue, )

Schedule invocation for later

Source

impl WasmRpc

pub fn schedule_cancelable_invocation( &self, scheduled_time: Datetime, method_name: &str, input: &DataValue, ) -> CancellationToken

Schedule invocation for later. Call cancel on the returned resource to cancel the invocation before the scheduled time.