pub enum RawUpdateDescription {
Automatic(ComponentRevision),
SnapshotBased(RawSnapshotBasedUpdate),
}Expand description
Raw update description used in oplog entries
Variants
Automatic(ComponentRevision)
Automatic update by replaying the oplog on the new version
SnapshotBased(RawSnapshotBasedUpdate)
Custom update by loading a given snapshot on the new version