pub fn with_checkpoint<T, E>(f: impl FnOnce(&Checkpoint) -> Result<T, E>) -> TExpand description
Creates a checkpoint, runs the given function, and reverts on error.
pub fn with_checkpoint<T, E>(f: impl FnOnce(&Checkpoint) -> Result<T, E>) -> TCreates a checkpoint, runs the given function, and reverts on error.