pub async fn with_checkpoint_async<T, E, F: Future<Output = Result<T, E>>>(
f: impl FnOnce(&Checkpoint) -> F,
) -> TExpand description
Creates a checkpoint, runs the given async function, and reverts on error.
pub async fn with_checkpoint_async<T, E, F: Future<Output = Result<T, E>>>(
f: impl FnOnce(&Checkpoint) -> F,
) -> TCreates a checkpoint, runs the given async function, and reverts on error.