pub async fn with_persistence_level_async<R, F: Future<Output = R>>(
level: PersistenceLevel,
f: impl FnOnce() -> F,
) -> RExpand description
Executes the given async function with the oplog persistence level set to the given value.
pub async fn with_persistence_level_async<R, F: Future<Output = R>>(
level: PersistenceLevel,
f: impl FnOnce() -> F,
) -> RExecutes the given async function with the oplog persistence level set to the given value.