pub struct Checkpoint { /* private fields */ }Expand description
A checkpoint that captures the current oplog index and can revert execution back to it.
Implementations
Sourceimpl Checkpoint
impl Checkpoint
Sourcepub fn run_or_revert<T, E>(&self, f: impl FnOnce() -> Result<T, E>) -> T
pub fn run_or_revert<T, E>(&self, f: impl FnOnce() -> Result<T, E>) -> T
Runs the given function, reverting to the checkpoint on error.
Sourcepub async fn run_or_revert_async<T, E, F: Future<Output = Result<T, E>>>(
&self,
f: impl FnOnce() -> F,
) -> T
pub async fn run_or_revert_async<T, E, F: Future<Output = Result<T, E>>>( &self, f: impl FnOnce() -> F, ) -> T
Runs the given async function, reverting to the checkpoint on error.
Sourcepub fn assert_or_revert(&self, condition: bool)
pub fn assert_or_revert(&self, condition: bool)
Reverts to the checkpoint if the condition is false.