pub struct WasmRpc { /* private fields */ }Expand description
An RPC client for invoking remote agents
Implementations
Sourceimpl WasmRpc
impl WasmRpc
Sourcepub fn async_invoke_and_await(
&self,
method_name: &str,
input: &DataValue,
) -> FutureInvokeResult
pub fn async_invoke_and_await( &self, method_name: &str, input: &DataValue, ) -> FutureInvokeResult
Invokes a remote method with the given parameters, and returns a future-invoke-result value which can
be polled for the result.
With this function it is possible to call multiple (different) agents simultaneously.
Sourceimpl WasmRpc
impl WasmRpc
Sourcepub fn schedule_invocation(
&self,
scheduled_time: Datetime,
method_name: &str,
input: &DataValue,
)
pub fn schedule_invocation( &self, scheduled_time: Datetime, method_name: &str, input: &DataValue, )
Schedule invocation for later
Sourceimpl WasmRpc
impl WasmRpc
Sourcepub fn schedule_cancelable_invocation(
&self,
scheduled_time: Datetime,
method_name: &str,
input: &DataValue,
) -> CancellationToken
pub fn schedule_cancelable_invocation( &self, scheduled_time: Datetime, method_name: &str, input: &DataValue, ) -> CancellationToken
Schedule invocation for later. Call cancel on the returned resource to cancel the invocation before the scheduled time.