pub async fn atomically_async<T, F: Future<Output = T>>( f: impl FnOnce() -> F, ) -> T
Executes the given async function as an atomic operation.
On panic the region is left open and the worker recovers + re-executes the block.