pub async fn atomically_async<T, F: Future<Output = T>>( f: impl FnOnce() -> F, ) -> T
Executes the given async function as an atomic operation.
In case of a failure, the whole operation will be re-executed during retry.