Skip to main contentModule builder
Source - NamedPolicy
- High-level named retry rule with an outer applicability predicate.
- Props
- Standard retry-property keys populated by the platform retry context.
- Policy
- High-level retry policy that keeps tree structure until conversion.
- Predicate
- High-level retry predicate that keeps tree structure until conversion.
- RetryBuilderError
- Validation errors produced when flattening high-level retry builders into raw WIT types.
- Value
- High-level predicate value accepted by the retry builder layer.