pub type LocalBoxFuture<'a, T> = Pin<Box<dyn Future<Output = T> + 'a>>;Expand description
A boxed local future. Used as the return type for transaction closures to allow the returned future to borrow from the transaction reference.
Use boxed to construct this from an async block.
Aliased Type
pub struct LocalBoxFuture<'a, T> { /* private fields */ }